==> wildfly-clustering-tomcat-20.0.0.Final-source-release.zip: wildfly-clustering-tomcat-20.0.0.Final/9.0/catalina/src/main/java/org/wildfly/clustering/tomcat/catalina/authenticator/Credentials.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.tomcat.catalina.authenticator;

/**
 * @author Paul Ferraro
 */
public class Credentials {
	private volatile AuthenticationType authType;
	private volatile String user;
	private volatile String password;

	public AuthenticationType getAuthenticationType() {
		return this.authType;
	}

	public void setAuthenticationType(AuthenticationType authType) {
		this.authType = authType;
	}

	public String getUser() {
		return this.user;
	}

	public void setUser(String user) {
		this.user = user;
	}

	public String getPassword() {
		return this.password;
	}

	public void setPassword(String password) {
		this.password = password;
	}
}

==> wildfly-clustering-tomcat-21.0.0.Final-source-release.zip: wildfly-clustering-tomcat-21.0.0.Final/10.1/catalina/src/main/java/org/wildfly/clustering/tomcat/catalina/authenticator/Credentials.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.tomcat.catalina.authenticator;

import java.io.Serializable;

/**
 * @author Paul Ferraro
 */
public class Credentials implements Serializable {
	private static final long serialVersionUID = 1672356165949721516L;

	private volatile AuthenticationType authType;
	private volatile String user;
	private volatile String password;

	public AuthenticationType getAuthenticationType() {
		return this.authType;
	}

	public void setAuthenticationType(AuthenticationType authType) {
		this.authType = authType;
	}

	public String getUser() {
		return this.user;
	}

	public void setUser(String user) {
		this.user = user;
	}

	public String getPassword() {
		return this.password;
	}

	public void setPassword(String password) {
		this.password = password;
	}
}
